@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.1.1-7
+# Application Name - Health Check V1.2.0-1
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -19,6 +19,10 @@ print "***** Start Imports *****"
 try:
         print "** Importing qtcore & gui **"
 	from PyQt4 import QtCore, QtGui
+        from PyQt4 import *
+        print "** Importing Pyside qtcore & gui **"
+        from PySide.QtCore import *
+        from PySide.QtGui import *
         print "** Importing ui.touchstub - accuracy tool **"
 	from ui.touchstub import aMainWindow
         print "** Importing sys **"
@@ -39,8 +43,8 @@ try:
 	import gn_cellinfo
         print "** Importing Hildon **"
 	import hildon
-	print "** Importing Threading **"
-	from threading import Thread
+	#print "** Importing Threading **"
+	#from threading import Thread
 	print "** Importing Time **"
 	import time
 	print "** Importing GTK **"
@@ -70,6 +74,10 @@ class camerasClass(QtGui.QMainWindow):
 
 	def __init__(self, *args):
 		apply(QtGui.QMainWindow.__init__, (self,) + args)
+		self.setAttribute(Qt.WA_Maemo5StackedWindow)
+		self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+
+		
 		print "** Set basic color on rectangle **"
 		self.color = QtGui.QColor(0, 0, 0) 
 		print "** Setting window details and loading form**"
@@ -85,20 +93,20 @@ class camerasClass(QtGui.QMainWindow):
 		self.lblCameraImage.setObjectName("lblCameraImage")
 		# Setup and draw the button
 		self.pushButton_cam = QtGui.QPushButton(self)
-		self.pushButton_cam.setGeometry(QtCore.QRect(10, 380, 331, 71))
+		self.pushButton_cam.setGeometry(QtCore.QRect(0, 380, 331, 71))
 		self.pushButton_cam.setObjectName("pushButton_cam")
 		self.pushButton_cam.setText("Front camera")
 		# Tell the button what to do when it is clicked.
 		QtCore.QObject.connect(self.pushButton_cam, QtCore.SIGNAL('clicked()'), self.updateTab3)
 		# Setup and draw the button
 		self.pushButton_cam2 = QtGui.QPushButton(self)
-		self.pushButton_cam2.setGeometry(QtCore.QRect(350, 380, 331, 71))
+		self.pushButton_cam2.setGeometry(QtCore.QRect(300, 380, 331, 71))
 		self.pushButton_cam2.setObjectName("pushButton_cam2")
 		self.pushButton_cam2.setText("Back camera")
 		# Tell the button what to do when it is clicked.
 		QtCore.QObject.connect(self.pushButton_cam2, QtCore.SIGNAL('clicked()'), self.updateTab3a)
 		self.exitb = QtGui.QPushButton('X', self)
-		self.exitb.setGeometry(QtCore.QRect(690, 380, 101, 71))
+		self.exitb.setGeometry(QtCore.QRect(600, 380, 101, 71))
 		self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.close)
 		
 	def updateTab3(self):
@@ -174,11 +182,12 @@ class camerasClass(QtGui.QMainWindow):
 			self.lblCameraImage.setPixmap(image)
 			print " ** Finished Back camera function **"
 
-class HelloWindow(QtGui.QMainWindow):
+class healthcheckWindow(QtGui.QMainWindow):
 
 	def __init__(self, *args):
 		apply(QtGui.QMainWindow.__init__, (self,) + args)
-		print "** Starting Hellowindow Class **"
+		self.setAttribute(Qt.WA_Maemo5StackedWindow)
+		print "** Starting healthcheckWindow Class **"
 		#checkpkgs()
 		global bname
 		#self.Qt::WA_Maemo5StackedWindow 
@@ -208,7 +217,7 @@ class HelloWindow(QtGui.QMainWindow):
 		self.exitb = QtGui.QPushButton('Exit', self)
 		self.exitb.move(10, 210)
 		self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.exitB)
-		print "** Completed Hellowindow Class load **"
+		print "** Completed healthcheckWindow Class load **"
  
 	def moveB(self):
 		print "** moving buttons **"
@@ -216,25 +225,26 @@ class HelloWindow(QtGui.QMainWindow):
 		if bname == "Move R":
 			bname = "Move L"
 			self.moveb.setText("Move L")
-			self.red.move(600, 10)
-			self.green.move(600, 50)
-			self.blue.move(600, 90)
-			self.moveb.move(600, 130)
-			self.exitb.move(600, 170)
+			self.red.move(500, 10)
+			self.green.move(500, 60)
+			self.blue.move(500, 110)
+			self.moveb.move(500, 160)
+			self.exitb.move(500, 210)
 		else:
 			self.moveb.setText("Move R")
 			bname = "Move R"
 			self.red.move(10, 10)
-			self.green.move(10, 50)
-			self.blue.move(10, 90)
-			self.moveb.move(10, 130)
-			self.exitb.move(10, 170)
+			self.green.move(10, 60)
+			self.blue.move(10, 110)
+			self.moveb.move(10, 160)
+			self.exitb.move(10, 210)
 		print "** moved buttons**"
 		
 
 	def exitB(self):
-		print "** Exiting Hellowindow Class - closing window **"
+		print "** Exiting healthcheckWindow Class - closing window **"
 		self.connect(self.exitb, QtCore.SIGNAL('clicked()'), self.close)
+		
   
 	def setRed(self):
 		if self.red.isChecked():
@@ -266,9 +276,10 @@ class HelloWindow(QtGui.QMainWindow):
 
 		self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
 		
-class Ui_MainWindow(object):
+class Ui_MainWindow(QtGui.QMainWindow):
 	def setupUi(self, MainWindow):
-
+                self.setAttribute(Qt.WA_Maemo5StackedWindow)
+                
 		print "** start SetupUi**"
 		# declaring the previous var_g_GPS location as a global in here, this allows it to be read in here.
 		global var_g_GPS
@@ -279,12 +290,13 @@ class Ui_MainWindow(object):
 		# Set the current font to Arial 12
 		font = QtGui.QFont()
 		font.setFamily("Arial")
-		font.setPointSize(12)
+		font.setPointSize(20)
 		# Set the Mainwindow to use this font
 		MainWindow.setFont(font)
                 # Not sure - QTDesigner did this bit - assuming it's loading up the form and a widget
 		self.centralwidget = QtGui.QWidget(MainWindow)
 		self.centralwidget.setObjectName("centralwidget")
+                app.setFont(font)
                 app.setStyleSheet("QPushButton {\
                     /* Let's make the size of the button 1,5 times of font size. */\
                     min-height: 1.5em;\
@@ -314,12 +326,12 @@ class Ui_MainWindow(object):
 
 		# Draw the Menubar
 		fremantle = MainWindow.menuBar().addMenu("Update");
-		act = fremantle.addAction("All")
+		act = fremantle.addAction("Update All")
 		QtCore.QObject.connect(act, QtCore.SIGNAL("triggered()"), self.updateAll)
-		actb = fremantle.addAction("System")
-		QtCore.QObject.connect(actb, QtCore.SIGNAL("triggered()"), self.updateTab1)
-		actc = fremantle.addAction("Comms")
-		QtCore.QObject.connect(actc, QtCore.SIGNAL("triggered()"), self.updateTab2)
+		#actb = fremantle.addAction("System")
+		#QtCore.QObject.connect(actb, QtCore.SIGNAL("triggered()"), self.updateTab1)
+		#actc = fremantle.addAction("Comms")
+		#QtCore.QObject.connect(actc, QtCore.SIGNAL("triggered()"), self.updateTab2)
 
 		# Creating the tab that i need for my application, and set it's size
 		self.tabWidget = QtGui.QTabWidget(self.centralwidget)
@@ -507,8 +519,10 @@ class Ui_MainWindow(object):
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_4)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
+		self.textBrowser.setOpenExternalLinks(True)
 		fsock = os.popen('cat /home/opt/healthcheck/about.txt').read()
-		self.textBrowser.setText (fsock)
+		self.textBrowser.setHtml(fsock)
+		# self.textBrowser.setText (fsock)
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -526,9 +540,13 @@ class Ui_MainWindow(object):
 		
 		# Set which tab you want showing on program load
 		print "** Show tab1 (0) **"
+		
+
 		self.tabWidget.setCurrentIndex(0)
 		QtCore.QMetaObject.connectSlotsByName(MainWindow)
 
+
+
 	def lclicked(self):
                 #print self.listWidget.currentRow()
                 #print self.listWidget.selectedItems()
@@ -546,7 +564,7 @@ class Ui_MainWindow(object):
                         b = os.popen('run-standalone.sh dbus-send --system --type=signal /com/nokia/mce/signal com.nokia.mce.signal.sig_device_orientation_ind').read()
                         coords = str(coords)
                         jaccel = str(coords) + str(b)
-                        self.listWidget.currentItem().setText("Accelerometer \t\t\t" + jaccel)
+                        self.listWidget.currentItem().setText("Accelerometer \t\t" + jaccel)
                 elif sela[0].strip() == "Battery Charge":
                         print " ** Getting battery charge**"
                         gl = os.popen('hal-device bme | awk \'/l.p/ {perc = $3}; /s_c/ {isch = $3} END if (isch == "false") {print perc" %"} else {print "Charging"}\'').read()
@@ -561,7 +579,7 @@ class Ui_MainWindow(object):
                         print " ** Getting Cam Shutter State**"
                         gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
                         gl = gl.strip()
-                        self.listWidget.currentItem().setText("Camera Shutter State \t\t" + gl.strip())
+                        self.listWidget.currentItem().setText("Camera Shutter State \t" + gl.strip())
                 elif sela[0].strip() == "FM Trans Strength":
                         print " ** Getting FM Transmitter power level **"
                         ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
@@ -576,7 +594,7 @@ class Ui_MainWindow(object):
                         print " ** Getting Keyboard Slider State**"
                         gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
                         gl = gl.strip()
-                        self.listWidget.currentItem().setText("Keyboard Slider State \t\t" + gl.strip())
+                        self.listWidget.currentItem().setText("Keyboard Slider State \t" + gl.strip())
                 elif sela[0].strip() == "Proximity Sensor State":
                         print " ** Getting proximity sensor state**"
                         gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
@@ -609,7 +627,7 @@ class Ui_MainWindow(object):
                         print " ** Getting Backlight Info **"
                         gl = os.popen('cat /sys/class/backlight/acx565akm/brightness').read()
                         gl = gl.strip()
-                        self.listWidget.currentItem().setText("Backlight Actual Level \t\t" + gl.strip())
+                        self.listWidget.currentItem().setText("Backlight Actual Level \t" + gl.strip())
                 elif sela[0].strip() == "Backlight Max Level":
                         print " ** Getting Backlight Info MAX **"
                         gl = os.popen('cat /sys/class/backlight/acx565akm/max_brightness').read()
@@ -639,7 +657,7 @@ class Ui_MainWindow(object):
                         print " ** Getting MMC Space **"
                         gl = os.popen('df /media/mmc1 | awk \'/mm/ {print $5}\'').read()
                         gl = gl.strip()
-                        self.listWidget.currentItem().setText("Memory Card % Used \t\t" + gl.strip())
+                        self.listWidget.currentItem().setText("Memory Card % Used \t" + gl.strip())
                 elif sela[0].strip() == "Memory Card Free":
                         print " ** Getting MMC MB Free **"
                         gl = os.popen('df -h /media/mmc1 | awk \'/mm/ {print $4}\'').read()
@@ -659,7 +677,7 @@ class Ui_MainWindow(object):
                         print " ** Getting rootfs % used **"
                         gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
                         gl = gl.strip()
-                        self.listWidget.currentItem().setText("Rootfs % Used \t\t\t" + gl.strip())
+                        self.listWidget.currentItem().setText("Rootfs % Used \t\t" + gl.strip())
                 elif sela[0].strip() == "Rootfs Free":
                         print " ** Getting rootfs free MB **"
                         gl = os.popen('df -h | awk \'$1 == "rootfs" {print $4}\'').read()
@@ -669,6 +687,12 @@ class Ui_MainWindow(object):
                         print " ** Getting load from uptime**"
                         ge = os.popen('uptime | sed \'s/.*e: //\'').read()
                         self.listWidget.currentItem().setText("System Load \t\t\t" + ge.strip())
+                elif sela[0].strip() == "Device Orientation":
+                        import dbus
+                        bus = dbus.SystemBus()             
+                        accel = bus.get_object('com.nokia.mce','/com/nokia/mce/request','com.nokia.mce.request') 
+                        orientation , stand , face , x , y , z = accel.get_device_orientation()
+                        self.listWidget.currentItem().setText("Device Orientation \t\t" + orientation)
                 else:
                         print "else", sela[0].strip()
 
@@ -733,6 +757,27 @@ class Ui_MainWindow(object):
 		self.listWidget2.addItem("GPS Position \t\t" + var_g_GPS.strip())
 		al = '/sbin/ifconfig | grep inet | grep -v 127.0.0.1 | awk \'{split($2,a,":");print a[2]}\''
 
+	def on_error(control, error, data):
+                print "location error: %d... quitting" % error
+                data.quit()
+
+        def on_changed(device, data):
+            if not device:
+                return
+            if device.fix:
+                if device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
+                    print "lat = %f, long = %f" % device.fix[4:6]
+                    data.stop()
+
+        def on_stop(control, data):
+            print "quitting"
+            data.quit()
+
+        def start_location(data):
+            data.start()
+            return False
+
+
 	def reboot_sys(self):
 		print "** reboot function running**"
 		self.CloseDialog = QtGui.QMessageBox.question(None, "Time for a Reboot!","Do you really want to reboot?",QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,QtGui.QMessageBox.No)
@@ -777,6 +822,28 @@ class Ui_MainWindow(object):
 		
 		if g.strip() == "3.2010.02-8":
 			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1.1")
+                elif g.strip() == "10.2010.19-1":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2")
+		elif g.strip() == "10.2010.19-1.002":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - USA Version")
+		elif g.strip() == "10.2010.19-1.003":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - Middle East and N Africa")
+                elif g.strip() == "10.2010.19-1.004":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - India Version")
+		elif g.strip() == "10.2010.19-1.201.3":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - UK Version")
+		elif g.strip() == "10.2010.12-9":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - Leaky Release")
+		elif g.strip() == "10.2010.12-9":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - Leaky Release")
+		elif g.strip() == "10.2010.12-9.1":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - Leaky Release")
+		elif g.strip() == "10.2010.12-9.2":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - Leaky Release")
+		elif g.strip() == "10.2010.12-9.3":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - Leaky Release")
+		elif g.strip() == "10.2010.12-9.001":
+			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.2 - Leaky Release")
 		elif g.strip() == "3.2010.02-8.002":
 			self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - PR 1.1.1")
 		elif g.strip() == "3.2010.02-8.001":
@@ -827,7 +894,7 @@ class Ui_MainWindow(object):
 		# This one reads fremantle version number (Firmware)
 		ga = os.popen('cat /proc/cpuinfo | grep Processor').read()
 		ga = ga.strip()[11:]		
-		self.listWidget.addItem("Processor Information \t\t" + ga.strip())
+		self.listWidget.addItem("Processor Information \t" + ga.strip())
 				
 		print " ** Getting board info**"
 		gb = os.popen('cat /proc/cpuinfo | grep Hardware').read()
@@ -837,12 +904,12 @@ class Ui_MainWindow(object):
 		print " ** Getting board info revision **"
 		gj = os.popen('cat /proc/cpuinfo | grep Revision').read()
 		gj = gj.strip()[11:]
-		self.listWidget.addItem("N900 Board Revision \t\t" + gj.strip())
+		self.listWidget.addItem("N900 Board Ver \t\t" + gj.strip())
 
 		print " ** Getting system locale**"
 		gc = os.popen('locale | grep LANG').read()
 		gc = gc.strip()[5:]
-		self.listWidget.addItem("System Locale \t\t\t" + gc.strip())
+		self.listWidget.addItem("System Locale \t\t" + gc.strip())
 
 		print " ** Getting boot count**"
 		gd = os.popen('cat /var/lib/dsme/boot_count').read()
@@ -862,12 +929,12 @@ class Ui_MainWindow(object):
 		print " ** Getting Cam Shutter State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/cam_shutter/state').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Camera Shutter State \t\t" + gl.strip())
+		self.listWidget.addItem("Camera Shutter State \t" + gl.strip())
 
 		print " ** Getting Keyboard Slider State**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/slide/state').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Keyboard Slider State \t\t" + gl.strip())
+		self.listWidget.addItem("Keyboard Slider State \t" + gl.strip())
 
 		print " ** Getting proximity sensor state**"
 		gl = os.popen('cat /sys/devices/platform/gpio-switch/proximity/state').read()
@@ -957,13 +1024,7 @@ class Ui_MainWindow(object):
                 time.sleep(2.0)
                 gl = os.popen('/usr/sbin/hciconfig hci0 | grep BD').read()            
 		s = gl.split(" ")
-                print "**** SHOW LINE****"
-                print gl
-                for words in s:
-                        print "**** word ****"
-                        print words
-
-                self.listWidget2.addItem("Bluetooth MAC \t\t" + s[2].strip())
+                self.listWidget2.addItem("Bluetooth MAC \t" + s[2].strip())
 
         # Funtion - update battery information
 	def updateBatt(self):
@@ -989,7 +1050,17 @@ class Ui_MainWindow(object):
 		coords = str(coords)
 		jaccel = str(coords) + str(b)
 		
-		self.listWidget.addItem("Accelerometer \t\t\t" + jaccel)
+		self.listWidget.addItem("Accelerometer \t\t" + jaccel)
+
+		import dbus
+                bus = dbus.SystemBus()             
+                accel = bus.get_object('com.nokia.mce','/com/nokia/mce/request','com.nokia.mce.request') 
+                orientation , stand , face , x , y , z = accel.get_device_orientation()
+                self.listWidget.addItem("Device Orientation \t\t" + orientation)
+                
+                
+                
+
 
 	def vibrateon(self):
                 
@@ -1040,7 +1111,7 @@ class Ui_MainWindow(object):
 		print " ** Getting rootfs % used **"
 		gl = os.popen('df | awk \'$1 == "rootfs" {print $5}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Rootfs % Used \t\t\t" + gl.strip())
+		self.listWidget.addItem("Rootfs % Used \t\t" + gl.strip())
 
 		print " ** Getting rootfs free MB **"
 		gl = os.popen('df -h | awk \'$1 == "rootfs" {print $4}\'').read()
@@ -1070,7 +1141,7 @@ class Ui_MainWindow(object):
 		print " ** Getting MMC Space **"
 		gl = os.popen('df /media/mmc1 | awk \'/mm/ {print $5}\'').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Memory Card % Used \t\t" + gl.strip())
+		self.listWidget.addItem("Memory Card % Used \t" + gl.strip())
 
 		print " ** Getting MMC MB Free **"
 		gl = os.popen('df -h /media/mmc1 | awk \'/mm/ {print $4}\'').read()
@@ -1085,7 +1156,7 @@ class Ui_MainWindow(object):
 		print " ** Getting Backlight Info **"
 		gl = os.popen('cat /sys/class/backlight/acx565akm/brightness').read()
 		gl = gl.strip()
-		self.listWidget.addItem("Backlight Actual Level \t\t" + gl.strip())
+		self.listWidget.addItem("Backlight Actual Level \t" + gl.strip())
 
 		print " ** Getting Backlight Info MAX **"
 		gl = os.popen('cat /sys/class/backlight/acx565akm/max_brightness').read()
@@ -1183,106 +1254,9 @@ class Ui_MainWindow(object):
                 progress.hide()
 
 	
-	def updateTab1(self):
-		print " ** Running tab1 - load progress**"
-		progress = QtGui.QProgressDialog("Please Wait", "Cancel", 0, 100, MainWindow)
-		progress.setWindowModality(QtCore.Qt.WindowModal)
-		progress.setAutoReset(True)
-		progress.setAutoClose(True)
-		progress.setMinimum(0)
-		progress.setMaximum(100)
-		progress.resize(800,200)
-		progress.setWindowTitle("Loading System")
-
-		progress.show()
-		QtGui.QApplication.processEvents()
-		time.sleep(0.5)
-                progress.setValue(0)
-
-                print " ** Running tab1 update ** "
-                self.listWidget.clear()
-                self.updaterootfs()
-                progress.setWindowTitle("Loading System - Rootfs")
-                QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                progress.setValue(20)
-                self.updateAccel()
-                progress.setWindowTitle("Loading System - Accelerometer")
-                QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                progress.setValue(40)
-                self.updateCPU()
-                progress.setWindowTitle("Loading System - CPU")
-                QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                progress.setValue(60)
-                self.updateMaemoV()
-                progress.setWindowTitle("Loading System - Firmware")
-                QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                progress.setValue(80)
-                progress.setWindowTitle("Loading System - Uptime")
-                QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                progress.setValue(90)
-                self.updateBatt()
-                progress.setWindowTitle("Loading System - Battery")
-                QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                self.listWidget.sortItems()
-                print " ** Finished tab 1 update **"
-
-                progress.setValue(100)
-                time.sleep(0.3)
-		print 'done'
-                progress.hide()
-
-	def updateTab2(self):
-		print " ** Running tab 2 progress**"
-		progress = QtGui.QProgressDialog("Please Wait", "Cancel", 0, 100, MainWindow)
-		progress.setWindowModality(QtCore.Qt.WindowModal)
-		progress.setAutoReset(True)
-		progress.setAutoClose(True)
-		progress.setMinimum(0)
-		progress.setMaximum(100)
-		progress.resize(800,200)
-		progress.setWindowTitle("Loading Comms")
-		progress.show()
-		QtGui.QApplication.processEvents()
-		time.sleep(0.5)
-                progress.setValue(0)
-
-                print " ** Starting tab 2 update**"
-		self.listWidget2.clear()
-		progress.setValue(20)
-		self.updateGPS(MainWindow)
-		progress.setWindowTitle("Loading Comms - GPS")
-		QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                progress.setValue(40)
-		self.Cellular(MainWindow)
-		progress.setWindowTitle("Loading Comms- Cell/Phone")
-		QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                progress.setValue(60)
-                self.updateBluetooth()
-                progress.setWindowTitle("Loading Comms- Bluetooth")
-                QtGui.QApplication.processEvents()
-                time.sleep(0.3)
-                progress.setValue(80)
-		self.updatenetname()
-		progress.setWindowTitle("Loading Comms - Networks")
-		self.listWidget2.sortItems()
-                progress.setValue(100)
-                time.sleep(0.3)
-                print " ** Finished tab 2 update **"
-
-		print 'done'
-                progress.hide()
-	
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.1.1-7", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.2.0-1", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System ", None, QtGui.QApplication.UnicodeUTF8))
 		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms ", None, QtGui.QApplication.UnicodeUTF8))
 		#self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
@@ -1293,8 +1267,6 @@ class Ui_MainWindow(object):
                 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
 	def Cellular(self,MainWindow):
 		print " ** Starting Cellular*"
-		#import dbus
-	
 		regstatus = gn_cellinfo.RegStatus()
 		signalstrength = gn_cellinfo.SignalStrength()
 
@@ -1332,7 +1304,7 @@ class Ui_MainWindow(object):
 		   
 		self.listWidget2.addItem("Cell RNC \t\t" + str(cell_rnc).strip())
 		self.listWidget2.addItem("Cell Status \t\t" + status)
-		self.listWidget2.addItem("Cell ID \t\t\t" + str(cell_id).strip())
+		self.listWidget2.addItem("Cell ID \t\t" + str(cell_id).strip())
 		self.listWidget2.addItem("Cell Services \t\t" + services)
 		print " ** Finishing Cellular **"
 
@@ -1397,6 +1369,7 @@ def start_location(data):
 	data.start()
 	return False
 
+
 # Start the main program/function
 if __name__ == "__main__":
 	print " ** Starting Main **"
@@ -1405,11 +1378,17 @@ if __name__ == "__main__":
 	print " ** Setting Main Window**"
 	MainWindow = QtGui.QMainWindow()
 	print "** Setting tool window #1**"
-	win = HelloWindow(MainWindow)
+	win = healthcheckWindow(MainWindow)
+	win.setAttribute(Qt.WA_Maemo5StackedWindow)
+	win.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
 	print "** Setting tool window #2**"
 	aui = aMainWindow(MainWindow)
+	aui.setAttribute(Qt.WA_Maemo5StackedWindow)
+	aui.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
 	print "** Setting Video window**"
 	imagewin = camerasClass(MainWindow)
+	imagewin.setAttribute(Qt.WA_Maemo5StackedWindow)
+	imagewin.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
 	print " ** Declare the UI**"
 	ui = Ui_MainWindow()
 	print " ** Draw everything and start the main function**"
